# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.self_service.account.v0 import account_membership_service_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2


class AccountMembershipServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAccountUserProfiles = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListAccountUserProfiles',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesResponse.FromString,
                )
        self.UpdateUserRole = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserRole',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleResponse.FromString,
                )
        self.UpdateUserAssignedEnvironments = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserAssignedEnvironments',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsResponse.FromString,
                )
        self.RemoveUserFromAccount = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/RemoveUserFromAccount',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountResponse.FromString,
                )
        self.InviteToJoinAccount = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/InviteToJoinAccount',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountResponse.FromString,
                )
        self.UpdateInvitation = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/UpdateInvitation',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationResponse.FromString,
                )
        self.AcceptInvitation = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/AcceptInvitation',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationResponse.FromString,
                )
        self.CancelJoiningInvitation = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/CancelJoiningInvitation',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationResponse.FromString,
                )
        self.ListAccountInvitations = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListAccountInvitations',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsResponse.FromString,
                )
        self.ListUserInvitations = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListUserInvitations',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsResponse.FromString,
                )
        self.ListUserMemberships = channel.unary_unary(
                '/qwak.self_service.account.v0.AccountMembershipService/ListUserMemberships',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsResponse.FromString,
                )


class AccountMembershipServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAccountUserProfiles(self, request, context):
        """List account users
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserRole(self, request, context):
        """Update user role
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserAssignedEnvironments(self, request, context):
        """Update user assigned environments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveUserFromAccount(self, request, context):
        """Remove user from account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteToJoinAccount(self, request, context):
        """Invite new member to join account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInvitation(self, request, context):
        """Update invitation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptInvitation(self, request, context):
        """Accept invitation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelJoiningInvitation(self, request, context):
        """Cancel a sent invitation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccountInvitations(self, request, context):
        """List account invitation, for getting invitation to join the account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserInvitations(self, request, context):
        """List user invitation, for getting invitation of the authenticated user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserMemberships(self, request, context):
        """List user membership, for getting invitation of the authenticated user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountMembershipServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListAccountUserProfiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccountUserProfiles,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesResponse.SerializeToString,
            ),
            'UpdateUserRole': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserRole,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleResponse.SerializeToString,
            ),
            'UpdateUserAssignedEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserAssignedEnvironments,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsResponse.SerializeToString,
            ),
            'RemoveUserFromAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveUserFromAccount,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountResponse.SerializeToString,
            ),
            'InviteToJoinAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteToJoinAccount,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountResponse.SerializeToString,
            ),
            'UpdateInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInvitation,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationResponse.SerializeToString,
            ),
            'AcceptInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptInvitation,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationResponse.SerializeToString,
            ),
            'CancelJoiningInvitation': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelJoiningInvitation,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationResponse.SerializeToString,
            ),
            'ListAccountInvitations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccountInvitations,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsResponse.SerializeToString,
            ),
            'ListUserInvitations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserInvitations,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsResponse.SerializeToString,
            ),
            'ListUserMemberships': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserMemberships,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.self_service.account.v0.AccountMembershipService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccountMembershipService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAccountUserProfiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListAccountUserProfiles',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountUserProfilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserRole',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserAssignedEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/UpdateUserAssignedEnvironments',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateUserAssignedEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveUserFromAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/RemoveUserFromAccount',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.RemoveUserFromAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InviteToJoinAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/InviteToJoinAccount',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.InviteToJoinAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/UpdateInvitation',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.UpdateInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcceptInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/AcceptInvitation',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.AcceptInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelJoiningInvitation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/CancelJoiningInvitation',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.CancelJoiningInvitationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccountInvitations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListAccountInvitations',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListAccountInvitationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserInvitations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListUserInvitations',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserInvitationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserMemberships(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.AccountMembershipService/ListUserMemberships',
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__service__pb2.ListUserMembershipsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Any, Union

from qwak.exceptions import QwakHTTPException
from qwak.model.adapters import (
    DataFrameInputAdapter,
    FileInputAdapter,
    ImageInputAdapter,
    JsonInputAdapter,
    MultiInputAdapter,
    NumpyInputAdapter,
    ProtoInputAdapter,
    StringInputAdapter,
    TfTensorInputAdapter,
)
from qwak.model.base import QwakModel

from .input_adapters.dataframe_input import DataframeInput
from .input_adapters.file_input import FileInput
from .input_adapters.image_input import ImageInput
from .input_adapters.json_input import JsonInput
from .input_adapters.string_input import StringInput
from .input_adapters.tf_tensor_input import TfTensorInput


def get_input_adapter(
    model: QwakModel,
) -> Union[JsonInput, DataframeInput, StringInput]:
    adapter = getattr(model.predict, "_input_adapter", "")

    class QwakInput(StringInput):
        def extract_user_func_args(self, data: str) -> Any:
            try:
                return adapter.extract_user_func_arg(data)
            except Exception as e:
                raise QwakHTTPException(
                    status_code=500,
                    message=f"Failed to deserialize input message. Error is: {e}. For more information "
                    f"please check model logs.",
                )

    class MultiFormatInput(QwakInput):
        pass

    mapping = {
        JsonInputAdapter: JsonInput,
        DataFrameInputAdapter: DataframeInput,
        StringInputAdapter: StringInput,
        ProtoInputAdapter: QwakInput,
        NumpyInputAdapter: QwakInput,
        MultiInputAdapter: MultiFormatInput,
        TfTensorInputAdapter: TfTensorInput,
        ImageInputAdapter: ImageInput,
        FileInputAdapter: FileInput,
    }

    if adapter:
        adapter.mappings = mapping
        for qwak_impl, runtime_impl in mapping.items():
            if isinstance(adapter, qwak_impl):
                if isinstance(adapter, DataFrameInputAdapter) and hasattr(
                    adapter, "input_orient"
                ):
                    return runtime_impl(input_orient=adapter.input_orient)
                return runtime_impl()

    return DataframeInput()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.account.v1 import account_service_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2


class AccountServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAccount = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/CreateAccount',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountResponse.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/GetAccount',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountResponse.FromString,
                )
        self.ListAccounts = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/ListAccounts',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsResponse.FromString,
                )
        self.UpdateAccount = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/UpdateAccount',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountResponse.FromString,
                )
        self.UpdateAccountPreferences = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/UpdateAccountPreferences',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesResponse.FromString,
                )
        self.UpdateAccountAcceptedTerms = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/UpdateAccountAcceptedTerms',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsResponse.FromString,
                )
        self.AddAutoBinding = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/AddAutoBinding',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingResponse.FromString,
                )
        self.RemoveAutoBinding = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/RemoveAutoBinding',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingResponse.FromString,
                )
        self.GetAccountBrief = channel.unary_unary(
                '/qwak.administration.account.v1.AccountService/GetAccountBrief',
                request_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefResponse.FromString,
                )


class AccountServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAccount(self, request, context):
        """Create account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Get a account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccounts(self, request, context):
        """List accounts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount(self, request, context):
        """Update account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccountPreferences(self, request, context):
        """Update account preferences
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccountAcceptedTerms(self, request, context):
        """Update account preferences
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddAutoBinding(self, request, context):
        """Add hostname to auto-bind to account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveAutoBinding(self, request, context):
        """Remove hostname to auto-bind to account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountBrief(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountResponse.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountResponse.SerializeToString,
            ),
            'ListAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccounts,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsResponse.SerializeToString,
            ),
            'UpdateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountResponse.SerializeToString,
            ),
            'UpdateAccountPreferences': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccountPreferences,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesResponse.SerializeToString,
            ),
            'UpdateAccountAcceptedTerms': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccountAcceptedTerms,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsResponse.SerializeToString,
            ),
            'AddAutoBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.AddAutoBinding,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingResponse.SerializeToString,
            ),
            'RemoveAutoBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveAutoBinding,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingResponse.SerializeToString,
            ),
            'GetAccountBrief': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountBrief,
                    request_deserializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.account.v1.AccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccountService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/CreateAccount',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.CreateAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/GetAccount',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/ListAccounts',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.ListAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/UpdateAccount',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccountPreferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/UpdateAccountPreferences',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountPreferencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccountAcceptedTerms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/UpdateAccountAcceptedTerms',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.UpdateAccountAcceptedTermsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddAutoBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/AddAutoBinding',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.AddAutoBindingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveAutoBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/RemoveAutoBinding',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.RemoveAutoBindingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountBrief(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.account.v1.AccountService/GetAccountBrief',
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefRequest.SerializeToString,
            qwak_dot_administration_dot_account_dot_v1_dot_account__service__pb2.GetAccountBriefResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import ast
from abc import ABC
from dataclasses import dataclass
from io import StringIO
from typing import TYPE_CHECKING, List

from _qwak_proto.qwak.feature_store.features.feature_set_pb2 import (
    Feature as ProtoFeature,
)
from _qwak_proto.qwak.features_operator.v3.features_operator_async_service_pb2 import (
    GetValidationResultResponse as ProtoGetValidationResultResponse,
)
from _qwak_proto.qwak.features_operator.v3.features_operator_pb2 import (
    SparkColumnDescription as ProtoSparkColumnDescription,
    ValidationFailureResponse as ProtoValidationFailureResponse,
    ValidationSuccessResponse as ProtoValidationSuccessResponse,
)
from qwak.exceptions import QwakException

if TYPE_CHECKING:
    try:
        import pandas as pd
    except ImportError:
        pass

_VALIDATION_RESPONSE_TYPE_SUCCESS = "success_response"
_VALIDATION_RESPONSE_TYPE_FAILURE = "failure_response"
_VALIDATION_RESPONSE_TYPE_TIMEOUT = "not_ready_response"


class ValidationResponse(ABC):
    pass


@dataclass
class TimeoutValidationResponse(ValidationResponse):
    pass


@dataclass
class FailureValidationResponse(ValidationResponse):
    phase: str
    message: str
    stdout: str
    stderr: str


@dataclass
class SuccessValidationResponse(ValidationResponse):
    sample: "pd.DataFrame"
    features: List[ProtoFeature]
    stdout: str
    stderr: str


class ValidationResponseFactory:
    @staticmethod
    def _get_features(
        spark_columns_description: List[ProtoSparkColumnDescription],
    ) -> List[ProtoFeature]:
        spark_features = []
        for spark_column in spark_columns_description:
            feature_col_name_list = str(spark_column.column_name).split(".")
            feature_name = (
                feature_col_name_list[1]
                if feature_col_name_list.__len__() == 2
                else spark_column.column_name
            )
            spark_features.append(
                ProtoFeature(
                    feature_name=feature_name,
                    feature_type=spark_column.spark_type,
                )
            )
        return spark_features

    @staticmethod
    def from_proto(
        validation_response: ProtoGetValidationResultResponse,
    ) -> ValidationResponse:
        try:
            import pandas as pd
        except ImportError:
            raise QwakException("Missing required Pandas dependency")

        validation_type: str = validation_response.WhichOneof("type")
        if validation_type == _VALIDATION_RESPONSE_TYPE_SUCCESS:
            success: ProtoValidationSuccessResponse = (
                validation_response.success_response
            )

            pd_sample: pd.DataFrame = pd.read_json(
                path_or_buf=StringIO(ast.literal_eval(success.sample)),
                dtype=success.spark_column_description,
            )

            features = ValidationResponseFactory._get_features(
                success.spark_column_description
            )
            return SuccessValidationResponse(
                sample=pd_sample,
                features=features,
                stdout=success.outputs.stdout,
                stderr=success.outputs.stderr,
            )
        elif validation_type == _VALIDATION_RESPONSE_TYPE_FAILURE:
            failure: ProtoValidationFailureResponse = (
                validation_response.failure_response
            )
            return FailureValidationResponse(
                phase=failure.phase,
                message=failure.error_message,
                stdout=failure.outputs.stdout,
                stderr=failure.outputs.stderr,
            )
        elif validation_type == _VALIDATION_RESPONSE_TYPE_TIMEOUT:
            return TimeoutValidationResponse()

        raise QwakException(f"Got unsupported response type: {validation_type}")



from copy import deepcopy
from typing import Any, Dict


def remove_none_value_keys(dict: Dict[Any, Any]):
    copy = deepcopy(dict)
    keys_to_remove = [k for k, v in dict.items() if v is None]

    for k in keys_to_remove:
        del copy[k]

    return copy



import io

from qwak.exceptions import QwakException

try:
    import numpy as np
except ImportError:
    pass
    # Numpy is supported either by supplying it as a dependency (or sub-dependency)
    # in your Python project, or during the runtime

from .base_output_adapter import BaseOutputAdapter


class NumpyOutputAdapter(BaseOutputAdapter):
    @staticmethod
    def http_content_type():
        return {"Content-Type": "application/x-npy"}

    @staticmethod
    def pack_user_func_return_value(return_result) -> bytes:
        if not isinstance(return_result, np.ndarray):
            raise QwakException(
                "XNpyOutputAdapter can only work with numpy.ndarray type"
            )
        try:
            results_buffer = io.BytesIO()
            # Disallow pickle: Changed in version 1.16.3: in response to CVE-2019-6446.
            np.save(results_buffer, return_result, allow_pickle=False)
            return results_buffer.getvalue()
        except Exception as e:
            raise ValueError(f"Failed to dump numpy array. Error is {e}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/serving/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.features import feature_set_types_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__types__pb2
from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/feature_store/serving/metadata.proto\x12*com.qwak.ai.feature.store.serving.metadata\x1a\x33qwak/feature_store/features/feature_set_types.proto\x1a(qwak/feature_store/entities/entity.proto\"\xb0\x02\n&StreamingAggregationFeaturesetMetadata\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12\x15\n\rfeatureset_id\x18\x03 \x01(\t\x12\x65\n streaming_aggregation_featureset\x18\x04 \x01(\x0b\x32;.qwak.feature.store.features.StreamingAggregationFeatureSet\x12=\n\x06\x65ntity\x18\x05 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\x12\x18\n\x10\x61vro_schema_json\x18\x06 \x01(\t\"\x8e\x02\n\x19\x42\x61tchFeaturesetV1Metadata\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12\x15\n\rfeatureset_id\x18\x03 \x01(\t\x12\x1d\n\x15qwak_protocol_version\x18\x04 \x01(\x05\x12K\n\x13\x62\x61tch_featureset_v1\x18\x05 \x01(\x0b\x32..qwak.feature.store.features.BatchFeatureSetV1\x12=\n\x06\x65ntity\x18\x06 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\"\x9a\x02\n\x1dStreamingFeaturesetV1Metadata\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12\x15\n\rfeatureset_id\x18\x03 \x01(\t\x12\x1d\n\x15qwak_protocol_version\x18\x04 \x01(\x05\x12S\n\x17streaming_featureset_v1\x18\x05 \x01(\x0b\x32\x32.qwak.feature.store.features.StreamingFeatureSetV1\x12=\n\x06\x65ntity\x18\x06 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\"\x7f\n\x1a\x46\x65\x61turesetMemoryUsageStats\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x15\n\rfeatureset_id\x18\x02 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x03 \x01(\t\x12\x19\n\x11online_used_bytes\x18\x04 \x01(\x03\x42,\n*com.qwak.ai.feature.store.serving.metadatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.serving.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.feature.store.serving.metadata'
  _globals['_STREAMINGAGGREGATIONFEATURESETMETADATA']._serialized_start=185
  _globals['_STREAMINGAGGREGATIONFEATURESETMETADATA']._serialized_end=489
  _globals['_BATCHFEATURESETV1METADATA']._serialized_start=492
  _globals['_BATCHFEATURESETV1METADATA']._serialized_end=762
  _globals['_STREAMINGFEATURESETV1METADATA']._serialized_start=765
  _globals['_STREAMINGFEATURESETV1METADATA']._serialized_end=1047
  _globals['_FEATURESETMEMORYUSAGESTATS']._serialized_start=1049
  _globals['_FEATURESETMEMORYUSAGESTATS']._serialized_end=1176
# @@protoc_insertion_point(module_scope)



import logging
import functools
import inspect
from inspect import BoundArguments, Signature
from typing import Any, Callable, Optional

import grpc
from qwak.exceptions import QwakException

logger = logging.getLogger()


def grpc_try_catch_wrapper(
    exception_message: str,
    reraise_non_grpc_error_original_exception: Optional[bool] = False,
) -> Callable:
    """A decorator for handling exceptions in client methods.

    This decorator wraps a function, catching any `grpc.RpcError` or other
    `Exception`. it re-raises them as a `QwakException`. The error message can be a
    static string or a template formatted with the decorated function's
    runtime arguments.

    Parameters
    ----------
    exception_message : str
        The error message template. This can be a static string or a format
        string using placeholders that match the decorated function's
        parameter names (e.g., "Failed on item {item_id}").
    reraise_non_grpc_error_original_exception : bool, optional
        If `True`, any exception that is *not* a `grpc.RpcError` will be
        re-raised in its original form. If `False` (the default), all
        exceptions are wrapped in `QwakException`.

    Returns
    -------
    Callable
        A decorator that wraps the function with the error handling logic.

    Raises
    ------
    QwakException
        Raised when the decorated function encounters any exception, unless
        `reraise_non_grpc_error_original_exception` is `True` and the error
        is not a `grpc.RpcError`. The new exception's message is formatted
        and includes details from the original error.
    Exception
        The original non-gRPC exception is re-raised if
        `reraise_non_grpc_error_original_exception` is set to `True`.

    Usage
    -----
    The decorator can be used with static strings and formatted strings

    **1. Formatted Error Messages**

    Use placeholders matching the function's parameter names to create
    context-specific error messages.

        @grpc_try_catch_wrapper("Failed to delete version {version_number} for FeatureSet {featureset_name}")
        def delete_featureset_version(self, featureset_name: str, version_number: int):
            # ... gRPC call ...

    If this function fails with a gRPC error, a `QwakException` is raised with a message like:
    `"Failed to delete version 2 for FeatureSet customer_churn - <original gRPC error code> - <original gRPC error details>."`

    **2. Static Error Messages**

    When no dynamic context is needed, a simple string is sufficient.

        @grpc_try_catch_wrapper("Failed to retrieve featuresets mapping")
        def get_featuresets_mapping(self):
            # ... gRPC call ...

    If this fails, the `QwakException` message will be:
    `"Failed to retrieve featuresets mapping - <original gRPC error code> - <original gRPC error details>."`
    """

    def decorator(function: Callable):
        @functools.wraps(function)
        def _inner_wrapper(*args, **kwargs):
            try:
                return function(*args, **kwargs)
            except grpc.RpcError as e:
                error_message: str = __get_error_msg(
                    exception_message=exception_message, e=e
                )

                formatted_message = __get_formatted_error_message(
                    exception_message=error_message,
                    function=function,
                    args=args,
                    kwargs=kwargs,
                )

                raise QwakException(formatted_message) from e

            except Exception as e:
                if reraise_non_grpc_error_original_exception:
                    raise e

                formatted_message = __get_formatted_error_message(
                    exception_message=exception_message,
                    function=function,
                    args=args,
                    kwargs=kwargs,
                )
                raise QwakException(f"{formatted_message}. Error is: {e}.") from e

        return _inner_wrapper

    return decorator


def __get_error_msg(exception_message: str, e: grpc.RpcError) -> str:
    err_msg: str = (
        f"{exception_message} - {e.code() if hasattr(e, 'code') else 'UNKNOWN'}"
    )
    if hasattr(e, "details") and e.details() is not None:
        err_msg: str = f"{err_msg} - {e.details()}"
    elif hasattr(e, "debug_error_string"):
        err_msg: str = f"{err_msg} - {e.debug_error_string()}"
    logger.debug(f"{err_msg}: {e}")
    return err_msg


def __get_formatted_error_message(
    exception_message: str, function: Callable, args: tuple[Any], kwargs: dict[str, Any]
) -> str:
    """Formats an error message string with the runtime arguments of a function.

    It inspects the function's signature and binds the passed args and kwargs
    to their parameter names, then uses them to format the message string.

    Args:
        exception_message (str): The error message template with placeholders.
        function (Callable): The decorated function.
        args (tuple[Any]): The positional arguments passed to the function.
        kwargs (dict[str, Any]): The keyword arguments passed to the function.

    Returns:
        str: The error message with placeholders filled in.
    """
    try:
        sig: Signature = inspect.signature(function)
        bound_args: BoundArguments = sig.bind(*args, **kwargs)
        bound_args.apply_defaults()

        return exception_message.format(**bound_args.arguments)
    except (ValueError, KeyError, TypeError):
        # Fallback if formatting fails (e.g., missing key in template)
        return exception_message



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.workspace import workspace_service_pb2 as qwak_dot_workspace_dot_workspace__service__pb2


class WorkspaceManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/CreateWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceResponse.FromString,
                )
        self.UpdateWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceResponse.FromString,
                )
        self.DeployWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/DeployWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceResponse.FromString,
                )
        self.UndeployWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/UndeployWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceResponse.FromString,
                )
        self.ListWorkspaces = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaces',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesResponse.FromString,
                )
        self.GetWorkspaceById = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/GetWorkspaceById',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdResponse.FromString,
                )
        self.DeleteWorkspace = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/DeleteWorkspace',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceResponse.FromString,
                )
        self.UpdateWorkspaceStatusFromEdge = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspaceStatusFromEdge',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeResponse.FromString,
                )
        self.ListWorkspaceImages = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaceImages',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesResponse.FromString,
                )
        self.RegisterWorkspaceTags = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/RegisterWorkspaceTags',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagResponse.FromString,
                )
        self.CountWorkspaces = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/CountWorkspaces',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesResponse.FromString,
                )
        self.GetDefaultWorkspaceValues = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/GetDefaultWorkspaceValues',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesResponse.FromString,
                )
        self.MarkBuildAsCopied = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/MarkBuildAsCopied',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedResponse.FromString,
                )
        self.CopyBuild = channel.unary_unary(
                '/qwak.workspace.management.WorkspaceManagementService/CopyBuild',
                request_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildResponse.FromString,
                )


class WorkspaceManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateWorkspace(self, request, context):
        """Create workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkspace(self, request, context):
        """Update existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployWorkspace(self, request, context):
        """Deploy existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployWorkspace(self, request, context):
        """Undeploy existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkspaces(self, request, context):
        """List existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkspaceById(self, request, context):
        """Get existing workspace by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWorkspace(self, request, context):
        """Delete existing workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkspaceStatusFromEdge(self, request, context):
        """Update workspace status from edge
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkspaceImages(self, request, context):
        """List workspace images
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterWorkspaceTags(self, request, context):
        """Create workspace tag
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountWorkspaces(self, request, context):
        """Count of workspaces
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDefaultWorkspaceValues(self, request, context):
        """Default values for workspace spec
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkBuildAsCopied(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CopyBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkspaceManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceResponse.SerializeToString,
            ),
            'UpdateWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceResponse.SerializeToString,
            ),
            'DeployWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceResponse.SerializeToString,
            ),
            'UndeployWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceResponse.SerializeToString,
            ),
            'ListWorkspaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkspaces,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesResponse.SerializeToString,
            ),
            'GetWorkspaceById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkspaceById,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdResponse.SerializeToString,
            ),
            'DeleteWorkspace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWorkspace,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceResponse.SerializeToString,
            ),
            'UpdateWorkspaceStatusFromEdge': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkspaceStatusFromEdge,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeResponse.SerializeToString,
            ),
            'ListWorkspaceImages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkspaceImages,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesResponse.SerializeToString,
            ),
            'RegisterWorkspaceTags': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterWorkspaceTags,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagResponse.SerializeToString,
            ),
            'CountWorkspaces': grpc.unary_unary_rpc_method_handler(
                    servicer.CountWorkspaces,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesResponse.SerializeToString,
            ),
            'GetDefaultWorkspaceValues': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDefaultWorkspaceValues,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesResponse.SerializeToString,
            ),
            'MarkBuildAsCopied': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkBuildAsCopied,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedResponse.SerializeToString,
            ),
            'CopyBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.CopyBuild,
                    request_deserializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildRequest.FromString,
                    response_serializer=qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.workspace.management.WorkspaceManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkspaceManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/CreateWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.CreateWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/DeployWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.DeployWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/UndeployWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.UndeployWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWorkspaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaces',
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWorkspaceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/GetWorkspaceById',
            qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.GetWorkspaceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWorkspace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/DeleteWorkspace',
            qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.DeleteWorkspaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWorkspaceStatusFromEdge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/UpdateWorkspaceStatusFromEdge',
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.UpdateWorkspaceStatusFromEdgeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWorkspaceImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/ListWorkspaceImages',
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.ListWorkspaceImagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterWorkspaceTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/RegisterWorkspaceTags',
            qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.RegisterWorkspaceTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CountWorkspaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/CountWorkspaces',
            qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.CountWorkspacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDefaultWorkspaceValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/GetDefaultWorkspaceValues',
            qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.GetDefaultWorkspaceValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkBuildAsCopied(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/MarkBuildAsCopied',
            qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.MarkBuildAsCopiedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CopyBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.workspace.management.WorkspaceManagementService/CopyBuild',
            qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildRequest.SerializeToString,
            qwak_dot_workspace_dot_workspace__service__pb2.CopyBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/data_catalog_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFqwak/administration/runtime_configuration/v0/data_catalog_config.proto\x12@qwak.administration.runtime_configuration.v0.data_catalog_config\"\xe9\x02\n\x18\x44\x61taCatalogConfiguration\x12\x63\n\x04glue\x18\x01 \x01(\x0b\x32S.qwak.administration.runtime_configuration.v0.data_catalog_config.GlueConfigurationH\x00\x12j\n\x08\x62ig_lake\x18\x02 \x01(\x0b\x32V.qwak.administration.runtime_configuration.v0.data_catalog_config.BigLakeConfigurationH\x00\x12t\n\runity_catalog\x18\x03 \x01(\x0b\x32[.qwak.administration.runtime_configuration.v0.data_catalog_config.UnityCatalogConfigurationH\x00\x42\x06\n\x04type\"}\n\x14\x42igLakeConfiguration\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12 \n\x18\x62ig_lake_connection_name\x18\x02 \x01(\t\x12\x19\n\x11\x62ig_lake_location\x18\x03 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x04 \x01(\t\"\x13\n\x11GlueConfiguration\">\n\x19UnityCatalogConfiguration\x12\x14\n\x0c\x63\x61talog_name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\tB\xe0\x01\n9com.jfrog.ml.runtime_configuration.v0.data_catalog_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.data_catalog_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9com.jfrog.ml.runtime_configuration.v0.data_catalog_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _globals['_DATACATALOGCONFIGURATION']._serialized_start=141
  _globals['_DATACATALOGCONFIGURATION']._serialized_end=502
  _globals['_BIGLAKECONFIGURATION']._serialized_start=504
  _globals['_BIGLAKECONFIGURATION']._serialized_end=629
  _globals['_GLUECONFIGURATION']._serialized_start=631
  _globals['_GLUECONFIGURATION']._serialized_end=650
  _globals['_UNITYCATALOGCONFIGURATION']._serialized_start=652
  _globals['_UNITYCATALOGCONFIGURATION']._serialized_end=714
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/hosting/aws/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCqwak/administration/runtime_configuration/v0/hosting/aws/auth.proto\x12\x38qwak.administration.runtime_configuration.v0.hosting.aws\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\"\x95\x01\n\rAWSAuthMethod\x12w\n\x1a\x61ws_security_token_service\x18\x02 \x01(\x0b\x32Q.qwak.administration.runtime_configuration.v0.hosting.aws.AWSSecurityTokenServiceH\x00\x42\x0b\n\tauth_type\"\x88\x01\n\x17\x41WSSecurityTokenService\x12\x61\n\x0esecret_key_ref\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefH\x00\x42\n\n\x08location\"\x94\x01\n\x14\x41WSScopedPermissions\x12n\n\x0eworkload_scope\x18\x01 \x01(\x0b\x32T.qwak.administration.runtime_configuration.v0.hosting.aws.AWSWorkloadPermissionScopeH\x00\x42\x0c\n\nscope_type\"\xf5\x03\n\x1a\x41WSWorkloadPermissionScope\x12k\n\x0f\x61nalytics_scope\x18\x01 \x01(\x0b\x32R.qwak.administration.runtime_configuration.v0.hosting.aws.AnalyticsPermissionScope\x12}\n\x19\x62\x61tch_inference_job_scope\x18\x02 \x01(\x0b\x32Z.qwak.administration.runtime_configuration.v0.hosting.aws.BatchInferenceJobPermissionScope\x12r\n\x13\x66\x65\x61ture_store_scope\x18\x03 \x01(\x0b\x32U.qwak.administration.runtime_configuration.v0.hosting.aws.FeatureStorePermissionScope\x12w\n\x16remote_build_job_scope\x18\x04 \x01(\x0b\x32W.qwak.administration.runtime_configuration.v0.hosting.aws.RemoteBuildJobPermissionScope\"x\n\x18\x41nalyticsPermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethod\"\x80\x01\n BatchInferenceJobPermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethod\"{\n\x1b\x46\x65\x61tureStorePermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethod\"}\n\x1dRemoteBuildJobPermissionScope\x12\\\n\x0b\x61uth_method\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.hosting.aws.AWSAuthMethodB\xd7\x01\n1com.jfrog.ml.runtime_configuration.v0.hosting.awsP\x01Z\x9f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/aws;hosting_awsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.hosting.aws.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n1com.jfrog.ml.runtime_configuration.v0.hosting.awsP\001Z\237\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/aws;hosting_aws'
  _globals['_AWSAUTHMETHOD']._serialized_start=195
  _globals['_AWSAUTHMETHOD']._serialized_end=344
  _globals['_AWSSECURITYTOKENSERVICE']._serialized_start=347
  _globals['_AWSSECURITYTOKENSERVICE']._serialized_end=483
  _globals['_AWSSCOPEDPERMISSIONS']._serialized_start=486
  _globals['_AWSSCOPEDPERMISSIONS']._serialized_end=634
  _globals['_AWSWORKLOADPERMISSIONSCOPE']._serialized_start=637
  _globals['_AWSWORKLOADPERMISSIONSCOPE']._serialized_end=1138
  _globals['_ANALYTICSPERMISSIONSCOPE']._serialized_start=1140
  _globals['_ANALYTICSPERMISSIONSCOPE']._serialized_end=1260
  _globals['_BATCHINFERENCEJOBPERMISSIONSCOPE']._serialized_start=1263
  _globals['_BATCHINFERENCEJOBPERMISSIONSCOPE']._serialized_end=1391
  _globals['_FEATURESTOREPERMISSIONSCOPE']._serialized_start=1393
  _globals['_FEATURESTOREPERMISSIONSCOPE']._serialized_end=1516
  _globals['_REMOTEBUILDJOBPERMISSIONSCOPE']._serialized_start=1518
  _globals['_REMOTEBUILDJOBPERMISSIONSCOPE']._serialized_end=1643
# @@protoc_insertion_point(module_scope)



from _qwak_proto.qwak.execution.v1.execution_service_pb2 import TriggerBackfillResponse
from _qwak_proto.qwak.execution.v1.execution_service_pb2_grpc import (
    FeatureStoreExecutionServiceServicer,
)
from grpc import RpcError


class ExecutionManagementServiceMock(FeatureStoreExecutionServiceServicer):
    def __init__(self):
        self._execution_id = None
        self._raise_exception_on_request = False

    def set_execution_id(self, execution_id: str) -> None:
        self._execution_id = execution_id

    def set_raise_exception(self):
        self._raise_exception_on_request = True

    def clear_raise_exception(self):
        self._raise_exception_on_request = False

    def TriggerBatchBackfill(self, request, context):
        if self._raise_exception_on_request:
            raise RpcError
        return TriggerBackfillResponse(execution_id=self._execution_id)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/hugging_face_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/qwak/integration/hugging_face_integration.proto\x12\x1bqwak.integration.management\"\xa4\x01\n\x16HuggingFaceIntegration\x12\x81\x01\n/hugging_face_api_token_system_secret_descriptor\x18\x01 \x01(\x0b\x32\x46.qwak.integration.management.HuggingFaceApiTokenSystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"\x8e\x01\n\x1aHuggingFaceIntegrationSpec\x12h\n\"hugging_face_api_token_auth_config\x18\x01 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceApiTokenAuthConfigH\x00\x42\x06\n\x04\x61uth\"\x8d\x01\n\x19HuggingFaceValidationSpec\x12h\n\"hugging_face_api_token_auth_config\x18\x01 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceApiTokenAuthConfigH\x00\x42\x06\n\x04\x61uth\"2\n\x1dHuggingFaceApiTokenAuthConfig\x12\x11\n\tapi_token\x18\x01 \x01(\t\"^\n)HuggingFaceApiTokenSystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x1c\n\x14\x61pi_token_secret_key\x18\x02 \x01(\t\"\x1f\n\x1dHuggingFaceIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.hugging_face_integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _globals['_HUGGINGFACEINTEGRATION']._serialized_start=81
  _globals['_HUGGINGFACEINTEGRATION']._serialized_end=245
  _globals['_HUGGINGFACEINTEGRATIONSPEC']._serialized_start=248
  _globals['_HUGGINGFACEINTEGRATIONSPEC']._serialized_end=390
  _globals['_HUGGINGFACEVALIDATIONSPEC']._serialized_start=393
  _globals['_HUGGINGFACEVALIDATIONSPEC']._serialized_end=534
  _globals['_HUGGINGFACEAPITOKENAUTHCONFIG']._serialized_start=536
  _globals['_HUGGINGFACEAPITOKENAUTHCONFIG']._serialized_end=586
  _globals['_HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR']._serialized_start=588
  _globals['_HUGGINGFACEAPITOKENSYSTEMSECRETDESCRIPTOR']._serialized_end=682
  _globals['_HUGGINGFACEINTEGRATIONOPTIONS']._serialized_start=684
  _globals['_HUGGINGFACEINTEGRATIONOPTIONS']._serialized_end=715
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.sources import batch_pb2 as qwak_dot_feature__store_dot_sources_dot_batch__pb2
from _qwak_proto.qwak.feature_store.sources import streaming_pb2 as qwak_dot_feature__store_dot_sources_dot_streaming__pb2
from _qwak_proto.qwak.feature_store.sources import data_source_attribute_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__attribute__pb2
from _qwak_proto.qwak.feature_store.v1.common.source_code import source_code_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_source__code_dot_source__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/feature_store/sources/data_source.proto\x12\x1aqwak.feature.store.sources\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&qwak/feature_store/sources/batch.proto\x1a*qwak/feature_store/sources/streaming.proto\x1a\x36qwak/feature_store/sources/data_source_attribute.proto\x1a:qwak/feature_store/v1/common/source_code/source_code.proto\"\xe3\x01\n\nDataSource\x12P\n\x16\x64\x61ta_source_definition\x18\x01 \x01(\x0b\x32\x30.qwak.feature.store.sources.DataSourceDefinition\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32..qwak.feature.store.sources.DataSourceMetadata\x12\x41\n\x0c\x66\x65\x61ture_sets\x18\x03 \x03(\x0b\x32+.qwak.feature.store.sources.FeatureSetBrief\"t\n\x14\x44\x61taSourceDefinition\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x44\n\x10\x64\x61ta_source_spec\x18\x02 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"\xc0\x01\n\x12\x44\x61taSourceMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"\xe3\x03\n\x0e\x44\x61taSourceSpec\x12?\n\x0c\x62\x61tch_source\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.sources.BatchSourceH\x00\x12\x44\n\rstream_source\x18\x02 \x01(\x0b\x32+.qwak.feature.store.sources.StreamingSourceH\x00\x12V\n\x10source_code_spec\x18\x03 \x01(\x0b\x32\x38.qwak.feature.store.v1.common.source_code.SourceCodeSpecB\x02\x18\x01\x12P\n\x16\x64\x61ta_source_attributes\x18\x04 \x01(\x0b\x32\x30.qwak.feature.store.sources.DataSourceAttributes\x12(\n\x1a\x66\x65\x61tureset_repository_name\x18\x05 \x01(\tB\x02\x18\x01H\x01\x12%\n\x1b\x64\x61ta_source_repository_name\x18\x06 \x01(\tH\x02\x42\x06\n\x04typeB\"\n featureset_repository_identifierB#\n!data_source_repository_identifier\"]\n\x0f\x46\x65\x61tureSetBrief\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_type\x18\x03 \x01(\x05\x42X\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sources.data_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _DATASOURCESPEC.fields_by_name['source_code_spec']._options = None
  _DATASOURCESPEC.fields_by_name['source_code_spec']._serialized_options = b'\030\001'
  _DATASOURCESPEC.fields_by_name['featureset_repository_name']._options = None
  _DATASOURCESPEC.fields_by_name['featureset_repository_name']._serialized_options = b'\030\001'
  _globals['_DATASOURCE']._serialized_start=310
  _globals['_DATASOURCE']._serialized_end=537
  _globals['_DATASOURCEDEFINITION']._serialized_start=539
  _globals['_DATASOURCEDEFINITION']._serialized_end=655
  _globals['_DATASOURCEMETADATA']._serialized_start=658
  _globals['_DATASOURCEMETADATA']._serialized_end=850
  _globals['_DATASOURCESPEC']._serialized_start=853
  _globals['_DATASOURCESPEC']._serialized_end=1336
  _globals['_FEATURESETBRIEF']._serialized_start=1338
  _globals['_FEATURESETBRIEF']._serialized_end=1431
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _GpuType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GpuTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GpuType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_GPU: _GpuType.ValueType  # 0
    NVIDIA_K80: _GpuType.ValueType  # 1
    NVIDIA_V100: _GpuType.ValueType  # 2
    NVIDIA_A100: _GpuType.ValueType  # 3
    NVIDIA_T4: _GpuType.ValueType  # 4
    NVIDIA_A10G: _GpuType.ValueType  # 5
    NVIDIA_L4: _GpuType.ValueType  # 6

class GpuType(_GpuType, metaclass=_GpuTypeEnumTypeWrapper): ...

INVALID_GPU: GpuType.ValueType  # 0
NVIDIA_K80: GpuType.ValueType  # 1
NVIDIA_V100: GpuType.ValueType  # 2
NVIDIA_A100: GpuType.ValueType  # 3
NVIDIA_T4: GpuType.ValueType  # 4
NVIDIA_A10G: GpuType.ValueType  # 5
NVIDIA_L4: GpuType.ValueType  # 6
global___GpuType = GpuType

class GpuResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_TYPE_FIELD_NUMBER: builtins.int
    GPU_AMOUNT_FIELD_NUMBER: builtins.int
    gpu_type: global___GpuType.ValueType
    """The type of the GPU"""
    gpu_amount: builtins.int
    """Amount of GPUs"""
    def __init__(
        self,
        *,
        gpu_type: global___GpuType.ValueType = ...,
        gpu_amount: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gpu_amount", b"gpu_amount", "gpu_type", b"gpu_type"]) -> None: ...

global___GpuResources = GpuResources



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.monitoring.v0 import alerting_channel_management_service_pb2 as qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2


class AlertingChannelManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/CreateAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelResponse.FromString,
                )
        self.UpdateAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/UpdateAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelResponse.FromString,
                )
        self.GetAlertingChannelById = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelById',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestById.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseById.FromString,
                )
        self.GetAlertingChannelByName = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelByName',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestByName.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseByName.FromString,
                )
        self.ListAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/ListAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelResponse.FromString,
                )
        self.DeleteAlertingChannel = channel.unary_unary(
                '/qwak.monitoring.v0.AlertingChannelManagementService/DeleteAlertingChannel',
                request_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelRequest.SerializeToString,
                response_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelResponse.FromString,
                )


class AlertingChannelManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAlertingChannel(self, request, context):
        """Create an alerting channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAlertingChannel(self, request, context):
        """Update an alerting channel
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAlertingChannelById(self, request, context):
        """Get an alerting channel by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAlertingChannelByName(self, request, context):
        """Get an alerting channel by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAlertingChannel(self, request, context):
        """List alerting channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAlertingChannel(self, request, context):
        """List alerting channels
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertingChannelManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelResponse.SerializeToString,
            ),
            'UpdateAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelResponse.SerializeToString,
            ),
            'GetAlertingChannelById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAlertingChannelById,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestById.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseById.SerializeToString,
            ),
            'GetAlertingChannelByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAlertingChannelByName,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestByName.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseByName.SerializeToString,
            ),
            'ListAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelResponse.SerializeToString,
            ),
            'DeleteAlertingChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAlertingChannel,
                    request_deserializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelRequest.FromString,
                    response_serializer=qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.monitoring.v0.AlertingChannelManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertingChannelManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/CreateAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.CreateAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/UpdateAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.UpdateAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAlertingChannelById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelById',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestById.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseById.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAlertingChannelByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/GetAlertingChannelByName',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelRequestByName.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.GetAlertingChannelResponseByName.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/ListAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.ListAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAlertingChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.monitoring.v0.AlertingChannelManagementService/DeleteAlertingChannel',
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelRequest.SerializeToString,
            qwak_dot_monitoring_dot_v0_dot_alerting__channel__management__service__pb2.DeleteAlertingChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/integration_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.integration import integration_pb2 as qwak_dot_integration_dot_integration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/integration/integration_service.proto\x12\x1bqwak.integration.management\x1a\"qwak/integration/integration.proto\"b\n\x18\x43reateIntegrationRequest\x12\x46\n\x10integration_spec\x18\x01 \x01(\x0b\x32,.qwak.integration.management.IntegrationSpec\"a\n\x19\x43reateIntegrationResponse\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x15\n\ris_successful\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"/\n\x15GetIntegrationRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"W\n\x16GetIntegrationResponse\x12=\n\x0bintegration\x18\x01 \x01(\x0b\x32(.qwak.integration.management.Integration\"\x18\n\x16ListIntegrationRequest\"Z\n\x18ListIntegrationsResponse\x12>\n\x0cintegrations\x18\x01 \x03(\x0b\x32(.qwak.integration.management.Integration\"z\n\x18UpdateIntegrationRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12\x46\n\x10integration_spec\x18\x02 \x01(\x0b\x32,.qwak.integration.management.IntegrationSpec\"\x1b\n\x19UpdateIntegrationResponse\"2\n\x18\x44\x65leteIntegrationRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"\x1b\n\x19\x44\x65leteIntegrationResponse\"m\n\x1aValidateIntegrationRequest\x12O\n\x0fvalidation_spec\x18\x01 \x01(\x0b\x32\x36.qwak.integration.management.IntegrationValidationSpec\"g\n\x1bValidateIntegrationResponse\x12H\n\x06result\x18\x01 \x01(\x0b\x32\x38.qwak.integration.management.ValidationIntegrationResult\"6\n\x1cGetIntegrationOptionsRequest\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\"a\n\x1dGetIntegrationOptionsResponse\x12@\n\x07options\x18\x01 \x01(\x0b\x32/.qwak.integration.management.IntegrationOptions2\xc4\x07\n\x1cIntegrationManagementService\x12\x82\x01\n\x11\x43reateIntegration\x12\x35.qwak.integration.management.CreateIntegrationRequest\x1a\x36.qwak.integration.management.CreateIntegrationResponse\x12y\n\x0eGetIntegration\x12\x32.qwak.integration.management.GetIntegrationRequest\x1a\x33.qwak.integration.management.GetIntegrationResponse\x12~\n\x10ListIntegrations\x12\x33.qwak.integration.management.ListIntegrationRequest\x1a\x35.qwak.integration.management.ListIntegrationsResponse\x12\x82\x01\n\x11UpdateIntegration\x12\x35.qwak.integration.management.UpdateIntegrationRequest\x1a\x36.qwak.integration.management.UpdateIntegrationResponse\x12\x82\x01\n\x11\x44\x65leteIntegration\x12\x35.qwak.integration.management.DeleteIntegrationRequest\x1a\x36.qwak.integration.management.DeleteIntegrationResponse\x12\x88\x01\n\x13ValidateIntegration\x12\x37.qwak.integration.management.ValidateIntegrationRequest\x1a\x38.qwak.integration.management.ValidateIntegrationResponse\x12\x8e\x01\n\x15GetIntegrationOptions\x12\x39.qwak.integration.management.GetIntegrationOptionsRequest\x1a:.qwak.integration.management.GetIntegrationOptionsResponseBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.integration_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _globals['_CREATEINTEGRATIONREQUEST']._serialized_start=111
  _globals['_CREATEINTEGRATIONREQUEST']._serialized_end=209
  _globals['_CREATEINTEGRATIONRESPONSE']._serialized_start=211
  _globals['_CREATEINTEGRATIONRESPONSE']._serialized_end=308
  _globals['_GETINTEGRATIONREQUEST']._serialized_start=310
  _globals['_GETINTEGRATIONREQUEST']._serialized_end=357
  _globals['_GETINTEGRATIONRESPONSE']._serialized_start=359
  _globals['_GETINTEGRATIONRESPONSE']._serialized_end=446
  _globals['_LISTINTEGRATIONREQUEST']._serialized_start=448
  _globals['_LISTINTEGRATIONREQUEST']._serialized_end=472
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_start=474
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_end=564
  _globals['_UPDATEINTEGRATIONREQUEST']._serialized_start=566
  _globals['_UPDATEINTEGRATIONREQUEST']._serialized_end=688
  _globals['_UPDATEINTEGRATIONRESPONSE']._serialized_start=690
  _globals['_UPDATEINTEGRATIONRESPONSE']._serialized_end=717
  _globals['_DELETEINTEGRATIONREQUEST']._serialized_start=719
  _globals['_DELETEINTEGRATIONREQUEST']._serialized_end=769
  _globals['_DELETEINTEGRATIONRESPONSE']._serialized_start=771
  _globals['_DELETEINTEGRATIONRESPONSE']._serialized_end=798
  _globals['_VALIDATEINTEGRATIONREQUEST']._serialized_start=800
  _globals['_VALIDATEINTEGRATIONREQUEST']._serialized_end=909
  _globals['_VALIDATEINTEGRATIONRESPONSE']._serialized_start=911
  _globals['_VALIDATEINTEGRATIONRESPONSE']._serialized_end=1014
  _globals['_GETINTEGRATIONOPTIONSREQUEST']._serialized_start=1016
  _globals['_GETINTEGRATIONOPTIONSREQUEST']._serialized_end=1070
  _globals['_GETINTEGRATIONOPTIONSRESPONSE']._serialized_start=1072
  _globals['_GETINTEGRATIONOPTIONSRESPONSE']._serialized_end=1169
  _globals['_INTEGRATIONMANAGEMENTSERVICE']._serialized_start=1172
  _globals['_INTEGRATIONMANAGEMENTSERVICE']._serialized_end=2136
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/action.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from _qwak_proto.qwak.automation.v1 import common_pb2 as qwak_dot_automation_dot_v1_dot_common__pb2
from _qwak_proto.qwak.automation.v1 import auto_scaling_pb2 as qwak_dot_automation_dot_v1_dot_auto__scaling__pb2
from _qwak_proto.qwak.batch_job.v1 import batch_job_service_pb2 as qwak_dot_batch__job_dot_v1_dot_batch__job__service__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fqwak/automation/v1/action.proto\x12\x12qwak.automation.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fqwak/automation/v1/common.proto\x1a%qwak/automation/v1/auto_scaling.proto\x1a)qwak/batch_job/v1/batch_job_service.proto\x1a/qwak/user_application/common/v0/resources.proto\"\x99\x01\n\x06\x41\x63tion\x12@\n\x0c\x62uild_deploy\x18\x01 \x01(\x0b\x32(.qwak.automation.v1.BuildAndDeployActionH\x00\x12\x43\n\x0f\x62\x61tch_execution\x18\x02 \x01(\x0b\x32(.qwak.automation.v1.BatchExecutionActionH\x00\x42\x08\n\x06\x61\x63tion\"Q\n\x14\x42\x61tchExecutionAction\x12\x39\n\x11\x65xecute_batch_job\x18\x01 \x01(\x0b\x32\x1e.qwak.batchjob.BatchJobRequest\"\xcd\x01\n\x14\x42uildAndDeployAction\x12\x31\n\nbuild_spec\x18\x01 \x01(\x0b\x32\x1d.qwak.automation.v1.BuildSpec\x12\x45\n\x14\x64\x65ployment_condition\x18\x02 \x01(\x0b\x32\'.qwak.automation.v1.DeploymentCondition\x12;\n\x0f\x64\x65ployment_spec\x18\x03 \x01(\x0b\x32\".qwak.automation.v1.DeploymentSpec\"\xb7\x01\n\x13\x44\x65ploymentCondition\x12@\n\x0c\x62uild_metric\x18\x01 \x01(\x0b\x32(.qwak.automation.v1.BuildMetricConditionH\x00\x12Q\n\x15\x64\x65ployed_build_metric\x18\x02 \x01(\x0b\x32\x30.qwak.automation.v1.DeployedBuildMetricConditionH\x00\x42\x0b\n\tcondition\"\x89\x01\n\x14\x42uildMetricCondition\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12I\n\x13threshold_direction\x18\x02 \x01(\x0e\x32,.qwak.automation.v1.MetricThresholdDirection\x12\x11\n\tthreshold\x18\x03 \x01(\t\"\x91\x01\n\x1c\x44\x65ployedBuildMetricCondition\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12I\n\x13threshold_direction\x18\x02 \x01(\x0e\x32,.qwak.automation.v1.MetricThresholdDirection\x12\x11\n\tvariation\x18\x03 \x01(\t\"\xdf\x01\n\x0e\x44\x65ploymentSpec\x12;\n\x0f\x64\x65ployment_size\x18\x01 \x01(\x0b\x32\".qwak.automation.v1.DeploymentSize\x12G\n\x10\x61\x64vanced_options\x18\x02 \x01(\x0b\x32-.qwak.automation.v1.AdvancedDeploymentOptions\x12\x1f\n\x17selected_variation_name\x18\x03 \x01(\t\x12\x14\n\x0c\x65nvironments\x18\x04 \x03(\t\x12\x10\n\x08\x65nv_vars\x18\x05 \x03(\t\"\xc4\x02\n\x19\x41\x64vancedDeploymentOptions\x12%\n\x1dnumber_of_http_server_workers\x18\x01 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x61\x65mon_mode\x18\x03 \x01(\x08\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x04 \x01(\t\x12\x42\n\x13\x61uto_scaling_config\x18\x05 \x01(\x0b\x32%.qwak.automation.v1.AutoScalingConfig\x12\x16\n\x0emax_batch_size\x18\x06 \x01(\x05\x12(\n deployment_process_timeout_limit\x18\x07 \x01(\x05\x12\'\n\x1fservice_account_key_secret_name\x18\x08 \x01(\t\"\xad\x02\n\x0e\x44\x65ploymentSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\x38\n\x0cmemory_units\x18\x04 \x01(\x0e\x32\x1e.qwak.automation.v1.MemoryUnitB\x02\x18\x01\x12;\n\rgpu_resources\x18\x05 \x01(\x0b\x32 .qwak.automation.v1.GpuResourcesB\x02\x18\x01\x12`\n\x1c\x63lient_pod_compute_resources\x18\x06 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\"\xc0\x04\n\tBuildSpec\x12<\n\x10git_model_source\x18\x01 \x01(\x0b\x32\".qwak.automation.v1.GitModelSource\x12\x41\n\nparameters\x18\x02 \x03(\x0b\x32-.qwak.automation.v1.BuildSpec.ParametersEntry\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x12\n\nbase_image\x18\x04 \x01(\t\x12\x18\n\x10\x61ssumed_iam_role\x18\x05 \x01(\t\x12/\n\x08resource\x18\x06 \x01(\x0b\x32\x1d.qwak.automation.v1.Resources\x12\x10\n\x08main_dir\x18\x07 \x01(\t\x12\x1c\n\x14\x64\x65pendency_file_path\x18\x08 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\t \x03(\t\x12\x16\n\x0egpu_compatible\x18\n \x01(\x08\x12.\n\npush_image\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x0fpurchase_option\x18\x0c \x01(\x0e\x32\".qwak.automation.v1.PurchaseOption\x12\'\n\x1fservice_account_key_secret_name\x18\r \x01(\t\x12\"\n\x1aprovision_instance_timeout\x18\x0e \x01(\x05\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x01\n\tResources\x12=\n\rcpu_resources\x18\x01 \x01(\x0b\x32 .qwak.automation.v1.CpuResourcesB\x02\x18\x01H\x00\x12=\n\rgpu_resources\x18\x02 \x01(\x0b\x32 .qwak.automation.v1.GpuResourcesB\x02\x18\x01H\x00\x12\x62\n\x1c\x63lient_pod_compute_resources\x18\x03 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResourcesH\x00\x42\n\n\x08resource\"h\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12\x34\n\x0cmemory_units\x18\x03 \x01(\x0e\x32\x1e.qwak.automation.v1.MemoryUnit\"Q\n\x0cGpuResources\x12-\n\x08gpu_type\x18\x01 \x01(\x0e\x32\x1b.qwak.automation.v1.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\"w\n\x0eGitModelSource\x12\x0f\n\x07git_uri\x18\x01 \x01(\t\x12#\n\x1bgit_credentials_secret_name\x18\x02 \x01(\t\x12\x12\n\ngit_branch\x18\x03 \x01(\t\x12\x1b\n\x13git_ssh_secret_name\x18\x04 \x01(\t*w\n\x07GpuType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06*+\n\nMemoryUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*)\n\x0ePurchaseOption\x12\r\n\tON_DEMAND\x10\x00\x12\x08\n\x04SPOT\x10\x01\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.action_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _DEPLOYMENTSIZE.fields_by_name['cpu']._options = None
  _DEPLOYMENTSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['memory_amount']._options = None
  _DEPLOYMENTSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['memory_units']._options = None
  _DEPLOYMENTSIZE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['gpu_resources']._options = None
  _DEPLOYMENTSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _BUILDSPEC_PARAMETERSENTRY._options = None
  _BUILDSPEC_PARAMETERSENTRY._serialized_options = b'8\001'
  _RESOURCES.fields_by_name['cpu_resources']._options = None
  _RESOURCES.fields_by_name['cpu_resources']._serialized_options = b'\030\001'
  _RESOURCES.fields_by_name['gpu_resources']._options = None
  _RESOURCES.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _globals['_GPUTYPE']._serialized_start=3170
  _globals['_GPUTYPE']._serialized_end=3289
  _globals['_MEMORYUNIT']._serialized_start=3291
  _globals['_MEMORYUNIT']._serialized_end=3334
  _globals['_PURCHASEOPTION']._serialized_start=3336
  _globals['_PURCHASEOPTION']._serialized_end=3377
  _globals['_ACTION']._serialized_start=252
  _globals['_ACTION']._serialized_end=405
  _globals['_BATCHEXECUTIONACTION']._serialized_start=407
  _globals['_BATCHEXECUTIONACTION']._serialized_end=488
  _globals['_BUILDANDDEPLOYACTION']._serialized_start=491
  _globals['_BUILDANDDEPLOYACTION']._serialized_end=696
  _globals['_DEPLOYMENTCONDITION']._serialized_start=699
  _globals['_DEPLOYMENTCONDITION']._serialized_end=882
  _globals['_BUILDMETRICCONDITION']._serialized_start=885
  _globals['_BUILDMETRICCONDITION']._serialized_end=1022
  _globals['_DEPLOYEDBUILDMETRICCONDITION']._serialized_start=1025
  _globals['_DEPLOYEDBUILDMETRICCONDITION']._serialized_end=1170
  _globals['_DEPLOYMENTSPEC']._serialized_start=1173
  _globals['_DEPLOYMENTSPEC']._serialized_end=1396
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_start=1399
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_end=1723
  _globals['_DEPLOYMENTSIZE']._serialized_start=1726
  _globals['_DEPLOYMENTSIZE']._serialized_end=2027
  _globals['_BUILDSPEC']._serialized_start=2030
  _globals['_BUILDSPEC']._serialized_end=2606
  _globals['_BUILDSPEC_PARAMETERSENTRY']._serialized_start=2557
  _globals['_BUILDSPEC_PARAMETERSENTRY']._serialized_end=2606
  _globals['_RESOURCES']._serialized_start=2609
  _globals['_RESOURCES']._serialized_end=2858
  _globals['_CPURESOURCES']._serialized_start=2860
  _globals['_CPURESOURCES']._serialized_end=2964
  _globals['_GPURESOURCES']._serialized_start=2966
  _globals['_GPURESOURCES']._serialized_end=3047
  _globals['_GITMODELSOURCE']._serialized_start=3049
  _globals['_GITMODELSOURCE']._serialized_end=3168
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/batch_job/v1/batch_job_resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/batch_job/v1/batch_job_resources.proto\x12\rqwak.batchjob\"L\n\x0cGpuResources\x12(\n\x08gpu_type\x18\x01 \x01(\x0e\x32\x16.qwak.batchjob.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05*{\n\x07GpuType\x12\x0f\n\x0bINVALID_GPU\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x42.\n\x19\x63om.qwak.ai.batch.job.apiP\x01Z\x0f./;inferencejobb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.batch_job.v1.batch_job_resources_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.qwak.ai.batch.job.apiP\001Z\017./;inferencejob'
  _globals['_GPUTYPE']._serialized_start=140
  _globals['_GPUTYPE']._serialized_end=263
  _globals['_GPURESOURCES']._serialized_start=62
  _globals['_GPURESOURCES']._serialized_end=138
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass, field
from typing import List

from _qwak_proto.qwak.models.models_pb2 import ModelMetadata as ModelMetadataProto

from qwak.qwak_client.builds.build import Build
from qwak.qwak_client.deployments.deployment import Deployment, EnvironmentAudienceRoute
from qwak.qwak_client.models.model import Model


@dataclass
class ModelMetadata:
    model: Model = field(default=None)
    deployments: List[Deployment] = field(default_factory=list)
    audience_routes: List[EnvironmentAudienceRoute] = field(default_factory=list)
    deployed_builds: List[Build] = field(default_factory=list)

    @staticmethod
    def from_proto(proto: ModelMetadataProto):
        return ModelMetadata(
            model=Model.from_proto(proto.model),
            deployments=[Deployment.from_proto(d) for d in proto.deployment_details],
            audience_routes=[
                EnvironmentAudienceRoute.from_proto(env_id, route)
                for env_id, env in proto.audience_routes_grouped_by_environment.items()
                for route in env.audience_routes
            ],
            deployed_builds=[Build.from_builds_management(b) for b in proto.build],
        )
